%global libzen_version  0.4.37

Name:		mediainfo
Version:	20.09
Release:	%mkrel 1
Summary:	Supplies technical and tag information about a video or audio file
Group:		Sound/Utilities
License:	BSD
URL:		https://mediaarea.net/
Source0:	https://mediaarea.net/download/source/mediainfo/%{version}/mediainfo_%{version}.tar.bz2

BuildRequires:  pkgconfig(libmediainfo) >= %{version}
BuildRequires:  pkgconfig(libzen) >= %{libzen_version}
BuildRequires:  pkgconfig(zlib)
BuildRequires:	dos2unix
BuildRequires:	wxgtku3.0-devel
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:	imagemagick

%description
MediaInfo supplies technical and tag information about a video or audio file.

What information can I get from MediaInfo?
* General: title, author, director, album, track number, date, duration...
* Video: codec, aspect, fps, bitrate...
* Audio: codec, sample rate, channels, language, bitrate...
* Text: language of subtitle
* Chapters: number of chapters, list of chapters

AV1, DivX, XviD, H263, H.263, H264, x264, ASP, AVC, iTunes, MPEG-1,
MPEG1, MPEG-2, MPEG2, MPEG-4, MPEG4, MP4, M4A, M4V, QuickTime,
RealVideo, RealAudio, RA, RM, MSMPEG4v1, MSMPEG4v2, MSMPEG4v3,
VOB, DVD, WMA, VMW, ASF, 3GP, 3GPP, 3GP2

What format (container) does MediaInfo support?
* Video: MKV, OGM, AVI, DivX, WMV, QuickTime, Real, MPEG-1,
  MPEG-2, MPEG-4, DVD (VOB) (Codecs: DivX, XviD, MSMPEG4, ASP,
  H.264, AVC...)
* Audio: OGG, MP3, WAV, RA, AC3, DTS, AAC, M4A, AU, AIFF
* Subtitles: SRT, SSA, ASS, SAMI

%package gui-wx
Summary:	wx-based GUI for %{name}
Group:		Sound/Utilities
Requires:	%{name}-gui-common = %{version}-%{release}
Provides:	%{name}-gui = %{version}-%{release}

%description gui-wx
wx-based graphical user interface for %{name}.

%package gui-qt
Summary:        Qt-based GUI for %{name}
Group:          Sound/Utilities
Requires:	%{name}-gui-common = %{version}-%{release}
Provides:	%{name}-gui = %{version}-%{release}
#The PLASMA5 service menu runs kdialog
Suggests:	kdialog

%description gui-qt
Qt-based graphical user interface for %{name}.

%package gui-common
Summary:        Common files for %{name} GUIs
Group:          Sound/Utilities
BuildArch:	noarch

%description gui-common
Common files for %{name} GUI packages.

%prep
%setup -q -n MediaInfo
%autopatch -p1

# fix EOLs and rights
dos2unix License.html History_*.txt
chmod 644 *.html *.txt Release/*.txt

%build
# build CLI
pushd Project/GNU/CLI
	autoreconf -vfi
	%configure2_5x --disable-static
	%make_build
popd

# now build GUI
pushd Project/GNU/GUI
	autoreconf -vfi
	%configure2_5x --disable-static
	%make_build
popd

# now build Qt GUI
pushd Project/QMake/GUI
	%qmake_qt5
	%make_build
popd

%install
pushd Project/GNU/CLI
	%make_install
popd

pushd Project/GNU/GUI
	%make_install
popd

pushd Project/QMake/GUI
	# as of 18.08.1 it overwrites the Wx binary
	#make_install INSTALL_ROOT=%{buildroot}
	install -m 755 %{name}-gui %{buildroot}%{_bindir}/%{name}-qt
popd

# icon
install -Dm 644 Source/Resource/Image/MediaInfo.png \
	%{buildroot}%{_datadir}/icons/hicolor/256x256/apps/%{name}.png

for i in 16 32 48 64 128; do
	mkdir -p %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps/
	convert -scale ${i} Source/Resource/Image/MediaInfo.png %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps/%{name}.png
done

# menu-entry for QT gui
mkdir -p %{buildroot}/%{_datadir}/applications/
cat > %{buildroot}/%{_datadir}/applications/%{name}-qt.desktop << EOF
[Desktop Entry]
Type=Application
Name=MediaInfo
Comment=Supplies technical and tag information about a video or audio file
Icon=%{name}
Exec=%{name}-qt %f
Terminal=false
Categories=AudioVideo;AudioVideoEditing;Qt;
EOF

# unneeded
rm -rf %{buildroot}%{_datadir}/apps/konqueror/servicemenus/%{name}-gui.desktop
rm -rf %{buildroot}%{_datadir}/kde4/services/ServiceMenus/%{name}-gui.desktop

# fix service menu
mv %{buildroot}%{_datadir}/kservices5/ServiceMenus/%{name}-gui.desktop \
  %{buildroot}%{_datadir}/kservices5/ServiceMenus/%{name}-qt.desktop

sed -i \
  -e 's|\(^Exec=\).*|\1kdialog -msgbox "$\(mediainfo-qt %u\)"|g' \
  -e 's|%{name}-gui|%{name}-qt|g' \
    %{buildroot}%{_datadir}/kservices5/ServiceMenus/%{name}-qt.desktop

%files
%doc Release/ReadMe_CLI_Linux.txt
%doc License.html History_CLI.txt
%{_bindir}/mediainfo

%files gui-wx
%doc Release/ReadMe_GUI_Linux.txt
%doc License.html History_GUI.txt
%{_bindir}/%{name}-gui
%{_datadir}/applications/%{name}-gui.desktop

%files gui-common
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/icons/hicolor/scalable/apps/mediainfo.svg
%{_datadir}/pixmaps/mediainfo.xpm
%{_datadir}/metainfo/%{name}-gui.metainfo.xml

%files gui-qt
%{_bindir}/%{name}-qt
%{_datadir}/applications/%{name}-qt.desktop
%{_datadir}/kservices5/ServiceMenus/%{name}-qt.desktop


%changelog
* Thu Mar 11 2021 neoclust <neoclust> 20.09-1.mga7
+ Revision: 1701488
- New version 20.09: Fixes CVE-2020-15395 (mga#27626)

* Sun Mar 31 2019 umeabot <umeabot> 18.12-2.mga7
+ Revision: 1383374
- Qt5 Rebuild

* Mon Feb 04 2019 zezinho <zezinho> 18.12-1.mga7
+ Revision: 1363226
- new version 18.12

* Sun Oct 28 2018 zezinho <zezinho> 18.08.1-1.mga7
+ Revision: 1326430
- new version 18.08.1 - switch to Qt5 - switch to WxGTK 3.0

* Sun Sep 23 2018 umeabot <umeabot> 17.10-2.mga7
+ Revision: 1299509
- Mageia 7 Mass Rebuild

* Wed Dec 06 2017 wally <wally> 17.10-1.mga7
+ Revision: 1181504
- new version 17.10

* Sun Oct 15 2017 wally <wally> 0.7.99-1.mga7
+ Revision: 1172171
- new version 0.7.99

* Wed May 17 2017 zezinho <zezinho> 0.7.95-1.mga6
+ Revision: 1102449
- add new svg icon and remove kde4 service menu
- fix file list
- new version

* Tue May 10 2016 tv <tv> 0.7.85-2.mga6
+ Revision: 1012074
- switch to FC patch for Qt build fix

* Tue May 10 2016 tv <tv> 0.7.85-1.mga6
+ Revision: 1012065
- use std build macros
- new release

* Thu Dec 31 2015 wally <wally> 0.7.80-1.mga6
+ Revision: 917160
- new version 0.7.80

* Sat Aug 29 2015 cjw <cjw> 0.7.76-2.mga6
+ Revision: 870814
- rebuild with gcc 5

* Thu Aug 13 2015 wally <wally> 0.7.76-1.mga6
+ Revision: 864483
- new version 0.7.76

* Thu Jun 25 2015 wally <wally> 0.7.74-1.mga6
+ Revision: 843522
- new version 0.7.74

* Wed Oct 15 2014 umeabot <umeabot> 0.7.70-3.mga5
+ Revision: 751209
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.7.70-2.mga5
+ Revision: 682333
- Mageia 5 Mass Rebuild

* Sat Sep 06 2014 wally <wally> 0.7.70-1.mga5
+ Revision: 672516
- new version 0.7.70

* Sun May 11 2014 wally <wally> 0.7.69-1.mga5
+ Revision: 621953
- new version 0.7.69

* Sat Apr 26 2014 wally <wally> 0.7.68-1.mga5
+ Revision: 618229
- new version 0.7.68

* Wed Feb 05 2014 wally <wally> 0.7.67-1.mga5
+ Revision: 583444
- new version 0.7.67

* Sat Oct 19 2013 umeabot <umeabot> 0.7.64-2.mga4
+ Revision: 529318
- Mageia 4 Mass Rebuild

* Mon Jul 08 2013 wally <wally> 0.7.64-1.mga4
+ Revision: 451456
- new version 0.7.64
- update URL

* Tue May 28 2013 wally <wally> 0.7.63-1.mga4
+ Revision: 429676
- new version 0.7.63
- switched to BSD-2-Clause license
- rediff P0 to fix qt gui build (from Frugalware)

* Sat Jan 12 2013 umeabot <umeabot> 0.7.61-2.mga3
+ Revision: 359890
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Nov 07 2012 fwang <fwang> 0.7.61-1.mga3
+ Revision: 315934
- update rpm group
- new version 0.7.61

* Mon Sep 03 2012 wally <wally> 0.7.60-1.mga3
+ Revision: 287652
- new version 0.7.60

* Sat Aug 11 2012 wally <wally> 0.7.59-1.mga3
+ Revision: 280541
- new version 0.7.59

* Sat Jun 02 2012 wally <wally> 0.7.58-1.mga3
+ Revision: 253442
- new version 0.7.58

* Tue May 29 2012 luigiwalser <luigiwalser> 0.7.57-1.mga3
+ Revision: 248858
- 0.7.57
- rediff patch0

* Thu Feb 02 2012 wally <wally> 0.7.53-1.mga2
+ Revision: 204078
- new version 0.7.53
- rediff P0

* Sat Dec 24 2011 wally <wally> 0.7.52-1.mga2
+ Revision: 187207
- new version 0.7.52

* Fri Nov 11 2011 wally <wally> 0.7.51-1.mga2
+ Revision: 166781
- new version 0.7.51
- redo P0

* Tue Sep 27 2011 wally <wally> 0.7.50-1.mga2
+ Revision: 149630
- new version 0.7.50
- new version 0.7.48
- add service menu entry for KDE4 (mga#2402)
+ ahmad <ahmad>
- Rebuild against wxgtk2.8 with enabled catch_segvs

* Mon Jul 18 2011 wally <wally> 0.7.47-1.mga2
+ Revision: 125992
- new version 0.7.47
- new version 0.7.46

* Sun Jun 19 2011 wally <wally> 0.7.45-1.mga2
+ Revision: 109993
- fix summaries and descriptions for GUI packages
- imported package mediainfo


* Sat Jun 18 2011 Jani Välimaa <wally@mandriva.org> 0.7.45-1mdv2011.0
+ Revision: 685928
- import mediainfo

